==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">&amp;Informazioni su...</translation>
    </message>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Revisione:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 si basa su QCAD, un software libero (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Ciò significa che tutti &lt;a href=&apos;%1&apos;&gt;possono partecipare&lt;/a&gt;!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Porzioni di questo software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Questo programma è distribuito nella speranza che sia utile, ma SENZA ALCUNA GARANZIA; senza neppure la garanzia implicita di NEGOZIABILITÀ o di APPLICABILITÀ PER UN PARTICOLARE SCOPO.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Nessuna informazione disponibile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Versione:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licenza:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Data corporatura:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Architettura:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Compiler:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 è un&apos;applicazione per computer-aided design (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 è software libero (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins e script add-ons sono soggetti alle rispettive licenze (vedi &quot;Plugin&quot; scheda).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Tutti i nomi di incendio o di prodotto sono marchi o marchi registrati dei rispettivi proprietari.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Porzioni di questo software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Porzioni di questo software © 2012 Nokia Corporation e / o della sua controllata(ies).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Nessun plugin trovato.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inattivo (riavviare)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Versione di prova:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Script Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nessuno script add-on disponibili.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni su...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmazione</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Modelli</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icone</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testing, feedback e correzioni minori</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Informazioni su QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Informazioni sui plugin</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Informazioni sui Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">&amp;Informazioni su...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">&amp;Informazioni su...</translation>
    </message>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Revisione:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 si basa su QCAD, un software libero (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Ciò significa che tutti &lt;a href=&apos;%1&apos;&gt;possono partecipare&lt;/a&gt;!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Porzioni di questo software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Questo programma è distribuito SENZA ALCUNA GARANZIA, INCLUSA la garanzia implicita PER DISEGNO, COMMERCIABILITÀ E IDONEITÀ AD UNO SCOPO PARTICOLARE.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Nessuna informazione disponibile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Versione Qt:</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Porzioni di questo software © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licenza:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Data Compilazione:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Architettura:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Compilatore:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation>Chiave di licenza:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 è un&apos;applicazione per computer-aided design (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 è un software libero (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins e script add-ons sono soggetti alle rispettive licenze (vedi scheda &quot;Plugins&quot;).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Tutti i nomi di marchio o di prodotto sono diritti registrati dai rispettivi proprietari.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Porzioni di questo software © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">Porzioni di questo software © 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Porzioni di questo software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Porzioni di questo software © 2012 Nokia Corporation e / o della sua controllata(ies).</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>No plugins found.</source>
        <translation>Nessun plugin trovato.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inattivo (riavviare)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Versione di prova:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Script Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nessuno script add-on disponibile.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Crediti</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni su...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmazione</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Modelli</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icone</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Test, feedback e correzioni minori</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Informazioni su QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Crediti</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Informazioni sui plugin</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Informazioni sui Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">&amp;Informazioni su...</translation>
    </message>
</context>
</TS>
